/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<blankanswer.h>)
#  include <blankanswer.h>
#endif
#if __has_include(<exporter.h>)
#  include <exporter.h>
#endif
#if __has_include(<fileopener.h>)
#  include <fileopener.h>
#endif
#if __has_include(<kwqcardmodel.h>)
#  include <kwqcardmodel.h>
#endif
#if __has_include(<kwqdocumentmodel.h>)
#  include <kwqdocumentmodel.h>
#endif
#if __has_include(<kwqrandomsortmodel.h>)
#  include <kwqrandomsortmodel.h>
#endif
#if __has_include(<languagelistmodel.h>)
#  include <languagelistmodel.h>
#endif
#if __has_include(<prefs.h>)
#  include <prefs.h>
#endif
#if __has_include(<stateprefs.h>)
#  include <stateprefs.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kwordquiz()
{
    qmlRegisterModule("org.kde.kwordquiz", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BlankAnswer>("org.kde.kwordquiz", 254);
    qmlRegisterTypesAndRevisions<Exporter>("org.kde.kwordquiz", 254);
    qmlRegisterEnum<Exporter::PrintStyle>("Exporter::PrintStyle");
    qmlRegisterTypesAndRevisions<FileOpener>("org.kde.kwordquiz", 254);
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<KWQCardModel>("org.kde.kwordquiz", 254);
    qmlRegisterEnum<KWQCardModel::ExtraRoles>("KWQCardModel::ExtraRoles");
    qmlRegisterTypesAndRevisions<KWQDocumentModel>("org.kde.kwordquiz", 254);
    qmlRegisterEnum<KWQDocumentModel::DocumentStatus>("KWQDocumentModel::DocumentStatus");
    qmlRegisterTypesAndRevisions<KWQRandomSortModel>("org.kde.kwordquiz", 254);
    qmlRegisterTypesAndRevisions<LanguageListModel>("org.kde.kwordquiz", 254);
    qmlRegisterTypesAndRevisions<Prefs>("org.kde.kwordquiz", 254);
    qmlRegisterEnum<Prefs::EnumStartSession>("Prefs::EnumStartSession");
    qmlRegisterEnum<Prefs::EnumTutorTiming>("Prefs::EnumTutorTiming");
    qmlRegisterEnum<Prefs::EnumTutorCardAppearance>("Prefs::EnumTutorCardAppearance");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<StatePrefs>("org.kde.kwordquiz", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kwordquiz", 254, 254);
}

static const QQmlModuleRegistration orgkdekwordquizRegistration("org.kde.kwordquiz", qml_register_types_org_kde_kwordquiz);
