/****************************************************************************
** Meta object code from reading C++ file 'prefs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../prefs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'prefs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5PrefsE_t {};
} // unnamed namespace

template <> constexpr inline auto Prefs::qt_create_metaobjectdata<qt_meta_tag_ZN5PrefsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Prefs",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "FirstRunChanged",
        "",
        "ShowSearchChanged",
        "StartSessionChanged",
        "EnableBlanksChanged",
        "EnterMoveChanged",
        "SpecialCharactersChanged",
        "ClearAllChanged",
        "ClearTextChanged",
        "ClearImageLinkChanged",
        "ClearSoundLinkChanged",
        "AutoCheckChanged",
        "AutoFlipChanged",
        "FlipDelayChanged",
        "HintErrorChanged",
        "CaseSensitiveAnswersChanged",
        "KeepDiscardChanged",
        "QuestionInLeftColumnChanged",
        "QuestionInRightColumnChanged",
        "RandomizeChanged",
        "PercentChanged",
        "FrontFontChanged",
        "FrontTextColorChanged",
        "FrontCardColorChanged",
        "FrontFrameColorChanged",
        "BackFontChanged",
        "BackTextColorChanged",
        "BackCardColorChanged",
        "BackFrameColorChanged",
        "ProvidersUrlChanged",
        "InstallationCommandChanged",
        "InstallPathChanged",
        "TutorTimingChanged",
        "TutorEveryChanged",
        "TutorMinChanged",
        "TutorMaxChanged",
        "TutorFlashCardGeometryChanged",
        "TutorCardAppearanceChanged",
        "LastVocabFileChanged",
        "StartExerciseAsSoonAsFileIsLoadedChanged",
        "firstRun",
        "isFirstRunImmutable",
        "defaultFirstRunValue",
        "showSearch",
        "isShowSearchImmutable",
        "defaultShowSearchValue",
        "startSession",
        "isStartSessionImmutable",
        "defaultStartSessionValue",
        "enableBlanks",
        "isEnableBlanksImmutable",
        "defaultEnableBlanksValue",
        "enterMove",
        "isEnterMoveImmutable",
        "defaultEnterMoveValue",
        "specialCharacters",
        "isSpecialCharactersImmutable",
        "defaultSpecialCharactersValue",
        "clearAll",
        "isClearAllImmutable",
        "defaultClearAllValue",
        "clearText",
        "isClearTextImmutable",
        "defaultClearTextValue",
        "clearImageLink",
        "isClearImageLinkImmutable",
        "defaultClearImageLinkValue",
        "clearSoundLink",
        "isClearSoundLinkImmutable",
        "defaultClearSoundLinkValue",
        "autoCheck",
        "isAutoCheckImmutable",
        "defaultAutoCheckValue",
        "autoFlip",
        "isAutoFlipImmutable",
        "defaultAutoFlipValue",
        "flipDelay",
        "isFlipDelayImmutable",
        "defaultFlipDelayValue",
        "hintError",
        "isHintErrorImmutable",
        "defaultHintErrorValue",
        "caseSensitiveAnswers",
        "isCaseSensitiveAnswersImmutable",
        "defaultCaseSensitiveAnswersValue",
        "keepDiscard",
        "isKeepDiscardImmutable",
        "defaultKeepDiscardValue",
        "questionInLeftColumn",
        "isQuestionInLeftColumnImmutable",
        "defaultQuestionInLeftColumnValue",
        "questionInRightColumn",
        "isQuestionInRightColumnImmutable",
        "defaultQuestionInRightColumnValue",
        "randomize",
        "isRandomizeImmutable",
        "defaultRandomizeValue",
        "percent",
        "isPercentImmutable",
        "defaultPercentValue",
        "frontFont",
        "QFont",
        "isFrontFontImmutable",
        "defaultFrontFontValue",
        "frontTextColor",
        "QColor",
        "isFrontTextColorImmutable",
        "defaultFrontTextColorValue",
        "frontCardColor",
        "isFrontCardColorImmutable",
        "defaultFrontCardColorValue",
        "frontFrameColor",
        "isFrontFrameColorImmutable",
        "defaultFrontFrameColorValue",
        "backFont",
        "isBackFontImmutable",
        "defaultBackFontValue",
        "backTextColor",
        "isBackTextColorImmutable",
        "defaultBackTextColorValue",
        "backCardColor",
        "isBackCardColorImmutable",
        "defaultBackCardColorValue",
        "backFrameColor",
        "isBackFrameColorImmutable",
        "defaultBackFrameColorValue",
        "providersUrl",
        "isProvidersUrlImmutable",
        "defaultProvidersUrlValue",
        "installationCommand",
        "isInstallationCommandImmutable",
        "defaultInstallationCommandValue",
        "installPath",
        "isInstallPathImmutable",
        "defaultInstallPathValue",
        "tutorTiming",
        "isTutorTimingImmutable",
        "defaultTutorTimingValue",
        "tutorEvery",
        "isTutorEveryImmutable",
        "defaultTutorEveryValue",
        "tutorMin",
        "isTutorMinImmutable",
        "defaultTutorMinValue",
        "tutorMax",
        "isTutorMaxImmutable",
        "defaultTutorMaxValue",
        "tutorFlashCardGeometry",
        "QRect",
        "isTutorFlashCardGeometryImmutable",
        "defaultTutorFlashCardGeometryValue",
        "tutorCardAppearance",
        "isTutorCardAppearanceImmutable",
        "defaultTutorCardAppearanceValue",
        "lastVocabFile",
        "isLastVocabFileImmutable",
        "startExerciseAsSoonAsFileIsLoaded",
        "isStartExerciseAsSoonAsFileIsLoadedImmutable",
        "defaultStartExerciseAsSoonAsFileIsLoadedValue",
        "EnumStartSession",
        "Editor",
        "Flashcard",
        "MultipleChoice",
        "QA",
        "EnumTutorTiming",
        "FixedInterval",
        "RandomInterval",
        "EnumTutorCardAppearance",
        "Native",
        "Minimalistic"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'FirstRunChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSearchChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StartSessionChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnableBlanksChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EnterMoveChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SpecialCharactersChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ClearAllChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ClearTextChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ClearImageLinkChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ClearSoundLinkChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoCheckChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoFlipChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FlipDelayChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HintErrorChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CaseSensitiveAnswersChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KeepDiscardChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'QuestionInLeftColumnChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'QuestionInRightColumnChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RandomizeChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PercentChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FrontFontChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FrontTextColorChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FrontCardColorChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FrontFrameColorChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BackFontChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BackTextColorChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BackCardColorChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BackFrameColorChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProvidersUrlChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InstallationCommandChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InstallPathChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorTimingChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorEveryChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorMinChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorMaxChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorFlashCardGeometryChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TutorCardAppearanceChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LastVocabFileChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StartExerciseAsSoonAsFileIsLoadedChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'firstRun'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isFirstRunImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFirstRunValue'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSearch'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isShowSearchImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowSearchValue'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'startSession'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isStartSessionImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStartSessionValue'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableBlanks'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isEnableBlanksImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableBlanksValue'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enterMove'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isEnterMoveImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnterMoveValue'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'specialCharacters'
        QtMocHelpers::PropertyData<QString>(60, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isSpecialCharactersImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpecialCharactersValue'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clearAll'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isClearAllImmutable'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClearAllValue'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clearText'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isClearTextImmutable'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClearTextValue'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clearImageLink'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isClearImageLinkImmutable'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClearImageLinkValue'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clearSoundLink'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isClearSoundLinkImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClearSoundLinkValue'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoCheck'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isAutoCheckImmutable'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoCheckValue'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoFlip'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isAutoFlipImmutable'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoFlipValue'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'flipDelay'
        QtMocHelpers::PropertyData<int>(81, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isFlipDelayImmutable'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFlipDelayValue'
        QtMocHelpers::PropertyData<int>(83, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hintError'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isHintErrorImmutable'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHintErrorValue'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'caseSensitiveAnswers'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isCaseSensitiveAnswersImmutable'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCaseSensitiveAnswersValue'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keepDiscard'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isKeepDiscardImmutable'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeepDiscardValue'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'questionInLeftColumn'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isQuestionInLeftColumnImmutable'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultQuestionInLeftColumnValue'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'questionInRightColumn'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isQuestionInRightColumnImmutable'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultQuestionInRightColumnValue'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'randomize'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isRandomizeImmutable'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRandomizeValue'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'percent'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isPercentImmutable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPercentValue'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'frontFont'
        QtMocHelpers::PropertyData<QFont>(105, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'isFrontFontImmutable'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrontFontValue'
        QtMocHelpers::PropertyData<QFont>(108, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'frontTextColor'
        QtMocHelpers::PropertyData<QColor>(109, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'isFrontTextColorImmutable'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrontTextColorValue'
        QtMocHelpers::PropertyData<QColor>(112, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'frontCardColor'
        QtMocHelpers::PropertyData<QColor>(113, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 22),
        // property 'isFrontCardColorImmutable'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrontCardColorValue'
        QtMocHelpers::PropertyData<QColor>(115, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'frontFrameColor'
        QtMocHelpers::PropertyData<QColor>(116, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'isFrontFrameColorImmutable'
        QtMocHelpers::PropertyData<bool>(117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrontFrameColorValue'
        QtMocHelpers::PropertyData<QColor>(118, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backFont'
        QtMocHelpers::PropertyData<QFont>(119, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'isBackFontImmutable'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBackFontValue'
        QtMocHelpers::PropertyData<QFont>(121, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backTextColor'
        QtMocHelpers::PropertyData<QColor>(122, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'isBackTextColorImmutable'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBackTextColorValue'
        QtMocHelpers::PropertyData<QColor>(124, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backCardColor'
        QtMocHelpers::PropertyData<QColor>(125, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'isBackCardColorImmutable'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBackCardColorValue'
        QtMocHelpers::PropertyData<QColor>(127, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backFrameColor'
        QtMocHelpers::PropertyData<QColor>(128, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 27),
        // property 'isBackFrameColorImmutable'
        QtMocHelpers::PropertyData<bool>(129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBackFrameColorValue'
        QtMocHelpers::PropertyData<QColor>(130, 0x80000000 | 110, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'providersUrl'
        QtMocHelpers::PropertyData<QString>(131, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isProvidersUrlImmutable'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProvidersUrlValue'
        QtMocHelpers::PropertyData<QString>(133, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'installationCommand'
        QtMocHelpers::PropertyData<QString>(134, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isInstallationCommandImmutable'
        QtMocHelpers::PropertyData<bool>(135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInstallationCommandValue'
        QtMocHelpers::PropertyData<QString>(136, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'installPath'
        QtMocHelpers::PropertyData<QString>(137, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isInstallPathImmutable'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInstallPathValue'
        QtMocHelpers::PropertyData<QString>(139, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tutorTiming'
        QtMocHelpers::PropertyData<int>(140, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isTutorTimingImmutable'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorTimingValue'
        QtMocHelpers::PropertyData<int>(142, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tutorEvery'
        QtMocHelpers::PropertyData<int>(143, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isTutorEveryImmutable'
        QtMocHelpers::PropertyData<bool>(144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorEveryValue'
        QtMocHelpers::PropertyData<int>(145, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tutorMin'
        QtMocHelpers::PropertyData<int>(146, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isTutorMinImmutable'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorMinValue'
        QtMocHelpers::PropertyData<int>(148, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tutorMax'
        QtMocHelpers::PropertyData<int>(149, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isTutorMaxImmutable'
        QtMocHelpers::PropertyData<bool>(150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorMaxValue'
        QtMocHelpers::PropertyData<int>(151, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tutorFlashCardGeometry'
        QtMocHelpers::PropertyData<QRect>(152, 0x80000000 | 153, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 35),
        // property 'isTutorFlashCardGeometryImmutable'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorFlashCardGeometryValue'
        QtMocHelpers::PropertyData<QRect>(155, 0x80000000 | 153, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'tutorCardAppearance'
        QtMocHelpers::PropertyData<int>(156, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isTutorCardAppearanceImmutable'
        QtMocHelpers::PropertyData<bool>(157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTutorCardAppearanceValue'
        QtMocHelpers::PropertyData<int>(158, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastVocabFile'
        QtMocHelpers::PropertyData<QString>(159, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isLastVocabFileImmutable'
        QtMocHelpers::PropertyData<bool>(160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'startExerciseAsSoonAsFileIsLoaded'
        QtMocHelpers::PropertyData<bool>(161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isStartExerciseAsSoonAsFileIsLoadedImmutable'
        QtMocHelpers::PropertyData<bool>(162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStartExerciseAsSoonAsFileIsLoadedValue'
        QtMocHelpers::PropertyData<bool>(163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EnumStartSession'
        QtMocHelpers::EnumData<enum EnumStartSession>(164, 164, QMC::EnumFlags{}).add({
            {  165, EnumStartSession::Editor },
            {  166, EnumStartSession::Flashcard },
            {  167, EnumStartSession::MultipleChoice },
            {  168, EnumStartSession::QA },
        }),
        // enum 'EnumTutorTiming'
        QtMocHelpers::EnumData<enum EnumTutorTiming>(169, 169, QMC::EnumFlags{}).add({
            {  170, EnumTutorTiming::FixedInterval },
            {  171, EnumTutorTiming::RandomInterval },
        }),
        // enum 'EnumTutorCardAppearance'
        QtMocHelpers::EnumData<enum EnumTutorCardAppearance>(172, 172, QMC::EnumFlags{}).add({
            {  173, EnumTutorCardAppearance::Native },
            {  174, EnumTutorCardAppearance::Minimalistic },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Prefs, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Prefs::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5PrefsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5PrefsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5PrefsE_t>.metaTypes,
    nullptr
} };

void Prefs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Prefs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->FirstRunChanged(); break;
        case 1: _t->ShowSearchChanged(); break;
        case 2: _t->StartSessionChanged(); break;
        case 3: _t->EnableBlanksChanged(); break;
        case 4: _t->EnterMoveChanged(); break;
        case 5: _t->SpecialCharactersChanged(); break;
        case 6: _t->ClearAllChanged(); break;
        case 7: _t->ClearTextChanged(); break;
        case 8: _t->ClearImageLinkChanged(); break;
        case 9: _t->ClearSoundLinkChanged(); break;
        case 10: _t->AutoCheckChanged(); break;
        case 11: _t->AutoFlipChanged(); break;
        case 12: _t->FlipDelayChanged(); break;
        case 13: _t->HintErrorChanged(); break;
        case 14: _t->CaseSensitiveAnswersChanged(); break;
        case 15: _t->KeepDiscardChanged(); break;
        case 16: _t->QuestionInLeftColumnChanged(); break;
        case 17: _t->QuestionInRightColumnChanged(); break;
        case 18: _t->RandomizeChanged(); break;
        case 19: _t->PercentChanged(); break;
        case 20: _t->FrontFontChanged(); break;
        case 21: _t->FrontTextColorChanged(); break;
        case 22: _t->FrontCardColorChanged(); break;
        case 23: _t->FrontFrameColorChanged(); break;
        case 24: _t->BackFontChanged(); break;
        case 25: _t->BackTextColorChanged(); break;
        case 26: _t->BackCardColorChanged(); break;
        case 27: _t->BackFrameColorChanged(); break;
        case 28: _t->ProvidersUrlChanged(); break;
        case 29: _t->InstallationCommandChanged(); break;
        case 30: _t->InstallPathChanged(); break;
        case 31: _t->TutorTimingChanged(); break;
        case 32: _t->TutorEveryChanged(); break;
        case 33: _t->TutorMinChanged(); break;
        case 34: _t->TutorMaxChanged(); break;
        case 35: _t->TutorFlashCardGeometryChanged(); break;
        case 36: _t->TutorCardAppearanceChanged(); break;
        case 37: _t->LastVocabFileChanged(); break;
        case 38: _t->StartExerciseAsSoonAsFileIsLoadedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FirstRunChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ShowSearchChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::StartSessionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::EnableBlanksChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::EnterMoveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::SpecialCharactersChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ClearAllChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ClearTextChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ClearImageLinkChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ClearSoundLinkChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::AutoCheckChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::AutoFlipChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FlipDelayChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::HintErrorChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::CaseSensitiveAnswersChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::KeepDiscardChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::QuestionInLeftColumnChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::QuestionInRightColumnChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::RandomizeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::PercentChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FrontFontChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FrontTextColorChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FrontCardColorChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::FrontFrameColorChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::BackFontChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::BackTextColorChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::BackCardColorChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::BackFrameColorChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::ProvidersUrlChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::InstallationCommandChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::InstallPathChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorTimingChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorEveryChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorMinChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorMaxChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorFlashCardGeometryChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::TutorCardAppearanceChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::LastVocabFileChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Prefs::*)()>(_a, &Prefs::StartExerciseAsSoonAsFileIsLoadedChanged, 38))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->firstRun(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFirstRunImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultFirstRunValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showSearch(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isShowSearchImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultShowSearchValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->startSession(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isStartSessionImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultStartSessionValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enableBlanks(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isEnableBlanksImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultEnableBlanksValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->enterMove(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isEnterMoveImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultEnterMoveValue(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->specialCharacters(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isSpecialCharactersImmutable(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->defaultSpecialCharactersValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->clearAll(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isClearAllImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultClearAllValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->clearText(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isClearTextImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultClearTextValue(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->clearImageLink(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isClearImageLinkImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->defaultClearImageLinkValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->clearSoundLink(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isClearSoundLinkImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultClearSoundLinkValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->autoCheck(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isAutoCheckImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultAutoCheckValue(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->autoFlip(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isAutoFlipImmutable(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->defaultAutoFlipValue(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->flipDelay(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isFlipDelayImmutable(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->defaultFlipDelayValue(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->hintError(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isHintErrorImmutable(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->defaultHintErrorValue(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->caseSensitiveAnswers(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isCaseSensitiveAnswersImmutable(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->defaultCaseSensitiveAnswersValue(); break;
        case 45: *reinterpret_cast<int*>(_v) = _t->keepDiscard(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isKeepDiscardImmutable(); break;
        case 47: *reinterpret_cast<int*>(_v) = _t->defaultKeepDiscardValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->questionInLeftColumn(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isQuestionInLeftColumnImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultQuestionInLeftColumnValue(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->questionInRightColumn(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isQuestionInRightColumnImmutable(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->defaultQuestionInRightColumnValue(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->randomize(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isRandomizeImmutable(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->defaultRandomizeValue(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->percent(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isPercentImmutable(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->defaultPercentValue(); break;
        case 60: *reinterpret_cast<QFont*>(_v) = _t->frontFont(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isFrontFontImmutable(); break;
        case 62: *reinterpret_cast<QFont*>(_v) = _t->defaultFrontFontValue(); break;
        case 63: *reinterpret_cast<QColor*>(_v) = _t->frontTextColor(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isFrontTextColorImmutable(); break;
        case 65: *reinterpret_cast<QColor*>(_v) = _t->defaultFrontTextColorValue(); break;
        case 66: *reinterpret_cast<QColor*>(_v) = _t->frontCardColor(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isFrontCardColorImmutable(); break;
        case 68: *reinterpret_cast<QColor*>(_v) = _t->defaultFrontCardColorValue(); break;
        case 69: *reinterpret_cast<QColor*>(_v) = _t->frontFrameColor(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isFrontFrameColorImmutable(); break;
        case 71: *reinterpret_cast<QColor*>(_v) = _t->defaultFrontFrameColorValue(); break;
        case 72: *reinterpret_cast<QFont*>(_v) = _t->backFont(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isBackFontImmutable(); break;
        case 74: *reinterpret_cast<QFont*>(_v) = _t->defaultBackFontValue(); break;
        case 75: *reinterpret_cast<QColor*>(_v) = _t->backTextColor(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isBackTextColorImmutable(); break;
        case 77: *reinterpret_cast<QColor*>(_v) = _t->defaultBackTextColorValue(); break;
        case 78: *reinterpret_cast<QColor*>(_v) = _t->backCardColor(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isBackCardColorImmutable(); break;
        case 80: *reinterpret_cast<QColor*>(_v) = _t->defaultBackCardColorValue(); break;
        case 81: *reinterpret_cast<QColor*>(_v) = _t->backFrameColor(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isBackFrameColorImmutable(); break;
        case 83: *reinterpret_cast<QColor*>(_v) = _t->defaultBackFrameColorValue(); break;
        case 84: *reinterpret_cast<QString*>(_v) = _t->providersUrl(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isProvidersUrlImmutable(); break;
        case 86: *reinterpret_cast<QString*>(_v) = _t->defaultProvidersUrlValue(); break;
        case 87: *reinterpret_cast<QString*>(_v) = _t->installationCommand(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isInstallationCommandImmutable(); break;
        case 89: *reinterpret_cast<QString*>(_v) = _t->defaultInstallationCommandValue(); break;
        case 90: *reinterpret_cast<QString*>(_v) = _t->installPath(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isInstallPathImmutable(); break;
        case 92: *reinterpret_cast<QString*>(_v) = _t->defaultInstallPathValue(); break;
        case 93: *reinterpret_cast<int*>(_v) = _t->tutorTiming(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isTutorTimingImmutable(); break;
        case 95: *reinterpret_cast<int*>(_v) = _t->defaultTutorTimingValue(); break;
        case 96: *reinterpret_cast<int*>(_v) = _t->tutorEvery(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isTutorEveryImmutable(); break;
        case 98: *reinterpret_cast<int*>(_v) = _t->defaultTutorEveryValue(); break;
        case 99: *reinterpret_cast<int*>(_v) = _t->tutorMin(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isTutorMinImmutable(); break;
        case 101: *reinterpret_cast<int*>(_v) = _t->defaultTutorMinValue(); break;
        case 102: *reinterpret_cast<int*>(_v) = _t->tutorMax(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isTutorMaxImmutable(); break;
        case 104: *reinterpret_cast<int*>(_v) = _t->defaultTutorMaxValue(); break;
        case 105: *reinterpret_cast<QRect*>(_v) = _t->tutorFlashCardGeometry(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isTutorFlashCardGeometryImmutable(); break;
        case 107: *reinterpret_cast<QRect*>(_v) = _t->defaultTutorFlashCardGeometryValue(); break;
        case 108: *reinterpret_cast<int*>(_v) = _t->tutorCardAppearance(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isTutorCardAppearanceImmutable(); break;
        case 110: *reinterpret_cast<int*>(_v) = _t->defaultTutorCardAppearanceValue(); break;
        case 111: *reinterpret_cast<QString*>(_v) = _t->lastVocabFile(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isLastVocabFileImmutable(); break;
        case 113: *reinterpret_cast<bool*>(_v) = _t->startExerciseAsSoonAsFileIsLoaded(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->isStartExerciseAsSoonAsFileIsLoadedImmutable(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->defaultStartExerciseAsSoonAsFileIsLoadedValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFirstRun(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowSearch(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setStartSession(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setEnableBlanks(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setEnterMove(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setSpecialCharacters(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setClearAll(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setClearText(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setClearImageLink(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setClearSoundLink(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setAutoCheck(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setAutoFlip(*reinterpret_cast<bool*>(_v)); break;
        case 36: _t->setFlipDelay(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setHintError(*reinterpret_cast<bool*>(_v)); break;
        case 42: _t->setCaseSensitiveAnswers(*reinterpret_cast<bool*>(_v)); break;
        case 45: _t->setKeepDiscard(*reinterpret_cast<int*>(_v)); break;
        case 48: _t->setQuestionInLeftColumn(*reinterpret_cast<bool*>(_v)); break;
        case 51: _t->setQuestionInRightColumn(*reinterpret_cast<bool*>(_v)); break;
        case 54: _t->setRandomize(*reinterpret_cast<bool*>(_v)); break;
        case 57: _t->setPercent(*reinterpret_cast<bool*>(_v)); break;
        case 60: _t->setFrontFont(*reinterpret_cast<QFont*>(_v)); break;
        case 63: _t->setFrontTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 66: _t->setFrontCardColor(*reinterpret_cast<QColor*>(_v)); break;
        case 69: _t->setFrontFrameColor(*reinterpret_cast<QColor*>(_v)); break;
        case 72: _t->setBackFont(*reinterpret_cast<QFont*>(_v)); break;
        case 75: _t->setBackTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 78: _t->setBackCardColor(*reinterpret_cast<QColor*>(_v)); break;
        case 81: _t->setBackFrameColor(*reinterpret_cast<QColor*>(_v)); break;
        case 84: _t->setProvidersUrl(*reinterpret_cast<QString*>(_v)); break;
        case 87: _t->setInstallationCommand(*reinterpret_cast<QString*>(_v)); break;
        case 90: _t->setInstallPath(*reinterpret_cast<QString*>(_v)); break;
        case 93: _t->setTutorTiming(*reinterpret_cast<int*>(_v)); break;
        case 96: _t->setTutorEvery(*reinterpret_cast<int*>(_v)); break;
        case 99: _t->setTutorMin(*reinterpret_cast<int*>(_v)); break;
        case 102: _t->setTutorMax(*reinterpret_cast<int*>(_v)); break;
        case 105: _t->setTutorFlashCardGeometry(*reinterpret_cast<QRect*>(_v)); break;
        case 108: _t->setTutorCardAppearance(*reinterpret_cast<int*>(_v)); break;
        case 111: _t->setLastVocabFile(*reinterpret_cast<QString*>(_v)); break;
        case 113: _t->setStartExerciseAsSoonAsFileIsLoaded(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Prefs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Prefs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5PrefsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Prefs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 39;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 116;
    }
    return _id;
}

// SIGNAL 0
void Prefs::FirstRunChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Prefs::ShowSearchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Prefs::StartSessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Prefs::EnableBlanksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Prefs::EnterMoveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Prefs::SpecialCharactersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Prefs::ClearAllChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Prefs::ClearTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Prefs::ClearImageLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Prefs::ClearSoundLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Prefs::AutoCheckChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Prefs::AutoFlipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Prefs::FlipDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Prefs::HintErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Prefs::CaseSensitiveAnswersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Prefs::KeepDiscardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Prefs::QuestionInLeftColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Prefs::QuestionInRightColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Prefs::RandomizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Prefs::PercentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Prefs::FrontFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Prefs::FrontTextColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Prefs::FrontCardColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Prefs::FrontFrameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Prefs::BackFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Prefs::BackTextColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Prefs::BackCardColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Prefs::BackFrameColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Prefs::ProvidersUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Prefs::InstallationCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Prefs::InstallPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Prefs::TutorTimingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void Prefs::TutorEveryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void Prefs::TutorMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void Prefs::TutorMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void Prefs::TutorFlashCardGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void Prefs::TutorCardAppearanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void Prefs::LastVocabFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void Prefs::StartExerciseAsSoonAsFileIsLoadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}
QT_WARNING_POP
