/****************************************************************************
** Meta object code from reading C++ file 'kwqcardmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kwordquiz-26.07.90/src/kwqcardmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwqcardmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KWQCardModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KWQCardModel::qt_create_metaobjectdata<qt_meta_tag_ZN12KWQCardModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWQCardModel",
        "QML.Element",
        "CardModel",
        "enabledChanged",
        "",
        "documentChanged",
        "titleChanged",
        "authorChanged",
        "authorContactChanged",
        "licenseChanged",
        "identifierLeftChanged",
        "identifierRightChanged",
        "langQuestionChanged",
        "langAnswerChanged",
        "multipleChoiceAvailableChanged",
        "reloaded",
        "createNew",
        "add",
        "question",
        "answer",
        "edit",
        "row",
        "addQuestionImage",
        "QUrl",
        "url",
        "addAnswerImage",
        "removeQuestionImage",
        "removeAnswerImage",
        "addQuestionSound",
        "addAnswerSound",
        "removeQuestionSound",
        "removeAnswerSound",
        "save",
        "document",
        "KEduVocDocument*",
        "title",
        "author",
        "authorContact",
        "license",
        "enabled",
        "identifierLeft",
        "identifierRight",
        "langQuestion",
        "langAnswer",
        "multipleChoiceAvailable",
        "ExtraRoles",
        "QuestionRole",
        "QuestionImageRole",
        "QuestionSoundRole",
        "AnswerRole",
        "AnswerImageRole",
        "AnswerSoundRole",
        "ExtraUserRoles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorContactChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'licenseChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identifierLeftChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identifierRightChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'langQuestionChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'langAnswerChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multipleChoiceAvailableChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloaded'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'createNew'
        QtMocHelpers::MethodData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'add'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Method 'edit'
        QtMocHelpers::MethodData<void(const int, const QString &, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Method 'addQuestionImage'
        QtMocHelpers::MethodData<void(const int, const QUrl &)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'addAnswerImage'
        QtMocHelpers::MethodData<void(const int, const QUrl &)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'removeQuestionImage'
        QtMocHelpers::MethodData<void(const int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Method 'removeAnswerImage'
        QtMocHelpers::MethodData<void(const int)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Method 'addQuestionSound'
        QtMocHelpers::MethodData<void(const int, const QUrl &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'addAnswerSound'
        QtMocHelpers::MethodData<void(const int, const QUrl &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { 0x80000000 | 23, 24 },
        }}),
        // Method 'removeQuestionSound'
        QtMocHelpers::MethodData<void(const int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Method 'removeAnswerSound'
        QtMocHelpers::MethodData<void(const int)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<bool()>(32, 4, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'document'
        QtMocHelpers::PropertyData<KEduVocDocument*>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'authorContact'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'license'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'identifierLeft'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'identifierRight'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'langQuestion'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'langAnswer'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'multipleChoiceAvailable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ExtraRoles'
        QtMocHelpers::EnumData<enum ExtraRoles>(45, 45, QMC::EnumFlags{}).add({
            {   46, ExtraRoles::QuestionRole },
            {   47, ExtraRoles::QuestionImageRole },
            {   48, ExtraRoles::QuestionSoundRole },
            {   49, ExtraRoles::AnswerRole },
            {   50, ExtraRoles::AnswerImageRole },
            {   51, ExtraRoles::AnswerSoundRole },
            {   52, ExtraRoles::ExtraUserRoles },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KWQCardModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWQCardModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWQCardModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWQCardModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KWQCardModelE_t>.metaTypes,
    nullptr
} };

void KWQCardModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWQCardModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->documentChanged(); break;
        case 2: _t->titleChanged(); break;
        case 3: _t->authorChanged(); break;
        case 4: _t->authorContactChanged(); break;
        case 5: _t->licenseChanged(); break;
        case 6: _t->identifierLeftChanged(); break;
        case 7: _t->identifierRightChanged(); break;
        case 8: _t->langQuestionChanged(); break;
        case 9: _t->langAnswerChanged(); break;
        case 10: _t->multipleChoiceAvailableChanged(); break;
        case 11: _t->reloaded(); break;
        case 12: _t->createNew(); break;
        case 13: _t->add((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->edit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->addQuestionImage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 16: _t->addAnswerImage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 17: _t->removeQuestionImage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->removeAnswerImage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->addQuestionSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 20: _t->addAnswerSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 21: _t->removeQuestionSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->removeAnswerSound((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::documentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::authorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::authorContactChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::licenseChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::identifierLeftChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::identifierRightChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::langQuestionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::langAnswerChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::multipleChoiceAvailableChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWQCardModel::*)()>(_a, &KWQCardModel::reloaded, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KEduVocDocument* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KEduVocDocument**>(_v) = _t->document(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->authorContact(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->license(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->identifierLeft(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->identifierRight(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->langQuestion(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->langAnswer(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->multipleChoiceAvailable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDocument(*reinterpret_cast<KEduVocDocument**>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setAuthor(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setAuthorContact(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setLicense(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setIdentifierLeft(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setIdentifierRight(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setLangQuestion(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setLangAnswer(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KWQCardModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWQCardModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWQCardModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KWQCardModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KWQCardModel::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWQCardModel::documentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWQCardModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KWQCardModel::authorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KWQCardModel::authorContactChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KWQCardModel::licenseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KWQCardModel::identifierLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KWQCardModel::identifierRightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KWQCardModel::langQuestionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KWQCardModel::langAnswerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KWQCardModel::multipleChoiceAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KWQCardModel::reloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
