// This file is generated by kconfig_compiler_kf6 from documentsettings.kcfg.
// All changes you do to this file will be lost.

#include "documentsettings.h"

DocumentSettings::DocumentSettings( const QString & fileurl )
  : KConfigSkeleton( QStringLiteral( "kwordquizrc" ) )
  , mParamfileurl(fileurl)
{
  setCurrentGroup( QStringLiteral( "Document %1" ).arg( mParamfileurl ) );

  mSizeHintColumnItem[0] = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SizeHintColumn0" ), mSizeHintColumn[0], 200 );
  mSizeHintColumnItem[0]->setLabel( QCoreApplication::translate("DocumentSettings", "Column widths") );
  addItem( mSizeHintColumnItem[0], QStringLiteral( "SizeHintColumn0" ) );
  mSizeHintColumnItem[1] = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "SizeHintColumn1" ), mSizeHintColumn[1], 200 );
  mSizeHintColumnItem[1]->setLabel( QCoreApplication::translate("DocumentSettings", "Column widths") );
  addItem( mSizeHintColumnItem[1], QStringLiteral( "SizeHintColumn1" ) );
  mKeyboardLayoutColumnItem[0] = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "KeyboardLayoutColumn0" ), mKeyboardLayoutColumn[0], QStringLiteral( "QString()" ) );
  mKeyboardLayoutColumnItem[0]->setLabel( QCoreApplication::translate("DocumentSettings", "Keyboard layouts") );
  addItem( mKeyboardLayoutColumnItem[0], QStringLiteral( "KeyboardLayoutColumn0" ) );
  mKeyboardLayoutColumnItem[1] = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "KeyboardLayoutColumn1" ), mKeyboardLayoutColumn[1], QStringLiteral( "QString()" ) );
  mKeyboardLayoutColumnItem[1]->setLabel( QCoreApplication::translate("DocumentSettings", "Keyboard layouts") );
  addItem( mKeyboardLayoutColumnItem[1], QStringLiteral( "KeyboardLayoutColumn1" ) );
}

DocumentSettings::~DocumentSettings()
{
}

